Date: 08 27, 2001 9:39:41 AM

# About Text Analysis International

The mission of Text Analysis International (TAI) is to revolutionize the way in which people process text.

TAI was founded in 1998 to develop technologies to analyze text deeply, accurately, and extensibly. VisualText embodies that technological approach, enabling a Natural Language Engineering (NLE) methodology for developing text analyzers. With NLE, the user controls the order of execution, the contexts to be worked in, and the actions to be taken in every step of the analysis of a text.

TAI's goals include an ever-greater degree of automation in the analysis of text, but always with a pragmatic, rather than theoretical, foundation. TAI is developing standardized bodies of knowledge, methods for text analysis, and diverse applications as it broadens its core technology. Rather than championing any particular paradigm, TAI seeks to exploit all paradigms and methods and to integrate methods wherever useful. Rather than over-committing to keyword, statistical, neural network, pattern, recursive grammar, or other approaches, TAI seeks to encompass all these approaches and more within its product sets.